@@ -6,18 +6,16 @@ from pathlib import Path
 
 import pkg_resources
 
-Package = namedtuple('Package', 'name version is_user')
+Package = namedtuple("Package", "name version is_user")
 
-__all__ = (
-    'install',
-)
+__all__ = ("install",)
 
 
 def install(pkgname, force_install=False):
-    '''
+    """
     Install a Python package from pypi.org or the given index server.
     The package is installed inside the user site directory.
-    '''
+    """
 
     if not force_install:
         user_path = Path(site.USER_SITE).resolve()
@@ -33,9 +31,9 @@ def install(pkgname, force_install=False):
                 return
 
     sys.stdout.flush()
-    cmdargs = [sys.executable, '-m', 'pip', 'install', '--user']
+    cmdargs = [sys.executable, "-m", "pip", "install", "--user"]
     if force_install:
-        cmdargs.append('-I')
+        cmdargs.append("-I")
     cmdargs.append(pkgname)
     subprocess.call(cmdargs)
     sys.stdout.flush()
